# Changelog

All notable changes to this project will be documented in this file.

## Latest Changes

## [0.2.1]

### Fixed

- Fix `--format json` incompatible issue for IDF branches earlier than 5.0
- Fix type annotations incompatible issue for python versions earlier than 3.7
- Fix f-string incompatible issue for python versions earlier than 3.7
- Fix unpack dictionary ending comma syntax error for python 3.4

## [0.2.0]

### Added

- Use `--format json` instead of `--json` with `idf_size.py`
